pub enum RenderCommand {
Draw(RoutedDrawCommand),
PushOffscreen {
source_layer: LayerId,
material: Material,
bounds: Rect,
},
PopOffscreen,
}Expand description
A command emitted by the compositor to control the GPU rendering pipeline.
Variants
Draw(RoutedDrawCommand)
Standard geometry draw call.
PushOffscreen
Instructs the GPU to bind an offscreen texture for the subsequent commands.
PopOffscreen
Instructs the GPU to unbind the offscreen texture, and draw it.